@@ -1,13 +1,20 @@
-# ==================================================================================================================
+# ====================================================================================================================
+# About the source code and the associated published paper               
+# ====================================================================================================================
 # This is the source code of DenMune Clustering Algorithm accompanied with the experimental work
 # which is published in Elsevier Pattern Recognition, Volume 109, January 2021
 # paper can be accessed from 107589 https://doi.org/10.1016/j.patcog.2020.107589
 # source code and several examples on using it, can be accessed from 
 # Gitbub's repository at https://github.com/egy1st/denmune-clustering-algorithm
 # Authors: Mohamed Abbas, Adel El-Zoghabi, and Amin Shoukry
-# Edition 0.0.0.2 updated 27-12-2021
+# Edition 0.0.2.3 Released 29-12-2021
+# PyPi package installation from  https://pypi.org/project/denmune/
 # ====================================================================================================================
 
+
+# ====================================================================================================================
+# About the DenMune Algorithm
+# ====================================================================================================================
 # DenMune Clustering Algorithm's Highlights
 # DenMune is a clustering algorithm that can find clusters of arbitrary size, shapes and densities in two-dimensions.
 # Higher dimensions are first reduced to 2-D using the t-sne.
@@ -15,6 +22,24 @@
 # The results show the superiority of DenMune.
 # =====================================================================================================================
 
+
+# =====================================================================================================================
+# About me
+# =====================================================================================================================
+# Name: Mohamed Ali Abbas
+# Egypt - Alexandria - Smouha
+# Cell-phone: +20-01007500290
+# Personal E-mail: mohamed.alyabbas@outlook.com
+# Business E-meal: 01@zerobytes.one
+# website: https://zerobytes.one
+# LinkedIn: https://www.linkedin.com/in/mohabbas/
+# Github: https://github.com/egy1st
+# Kaggle: https://www.kaggle.com/egyfirst
+# Udemy: https://www.udemy.com/user/mohammad-ali-abbas/
+# Facebook: https://www.facebook.com/ZeroBytes.One
+# =====================================================================================================================
+
+
 import numpy as np
 import ngtpy
 import seaborn as sns
@@ -69,7 +94,7 @@ class DenMune():
                 end = time.time()
                 if verpose:
                     print('using t-SNE', dataset, ' dataset has been reduced to 2-d in ', end-start, ' seconds')
-                    
+
             data = genfromtxt(file_2d , delimiter='\t')
 
 
@@ -589,7 +614,7 @@ class DenMune():
     def generate_tsne(self, data, file_2d, d):
         
         
-        dim_two = TSNE(n_components=d).fit_transform(data)
+        dim_two = TSNE(n_components=d, random_state=13, init='random').fit_transform(data)
 
         mystr = ""
         data_len = len (dim_two)
@@ -664,7 +689,4 @@ class DenMune():
 
         else:
             return 'Max classes numbers are 103 classes'
-
-
-    
-   
\ No newline at end of file
+            
\ No newline at end of file
